@@ -351,8 +351,17 @@ if __name__ == '__main__':
 
     # scr_pdfs = r'C:\Users\RD-PC\Desktop\RGB_to_HSV\get_pdf_pic\src'
     # dst_pdfs = r'C:\Users\RD-PC\Desktop\RGB_to_HSV\get_pdf_pic\dst_pdfs'
-    scr_pdfs = sys.argv[1]
-    dst_pdfs = sys.argv[2]
-    tb_path = sys.argv[3]
-    iscontaincover = int(sys.argv[4])
+    # scr_pdfs = sys.argv[1]
+    # dst_pdfs = sys.argv[2]
+    # tb_path = sys.argv[3]
+    # iscontaincover = int(sys.argv[4])
+    # split_pdfs_in_tb(tb_path,scr_pdfs,dst_pdfs,iscontaincover)
+    scr_pdfs = r"D:\0000待切分PDf"
+    dst_pdfs = r"D:\0000拆分保存位置"
+    tb_path = r'C:\Users\wangsa\Desktop\文档处理控制表【基于OCR识别结果校验】_20230227172646.xlsx'
+    iscontaincover = 1
+    # scr_pdfs = sys.argv[1]
+    # dst_pdfs = sys.argv[2]
+    # tb_path = sys.argv[3]
+    # iscontaincover = int(sys.argv[4])
     split_pdfs_in_tb(tb_path,scr_pdfs,dst_pdfs,iscontaincover)
